@@ -218,8 +218,9 @@ class dyn_obj:
         self.pa_axes.dynamic_6DOF(quat_list, None, None, None)
         self.non_rot.dynamic_6DOF(None, x_list, y_list, z_list)
 
-    def apply_streamline(self, staticity, int_x, int_y, int_z, frames, thickness):
+    def apply_streamline(self, staticity, int_x, int_y, int_z, thickness):
         name = self.name+'_streamline'
+        frames = self.frames
 
         int_size = len(int_x)
         int_coords = np.zeros((int_size, 3))
